
clear
version 14.2
set more off
capture cd "$GoogleDriveLaptop"
capture cd "$GoogleDriveWork"
cd ".\Talks\2017\ASA_CPS\PowerSampleSize\examples"
set seed 142

local mu_null = 0
local mu_alt = 1
local sd = 1
local z_crit = round(-1*invnormal(0.05), 0.01)
local z_crit_label = `z_crit' + 0.75


// NULL ONLY
#delimit ;
twoway  (function y=normalden(x,`mu_null',`sd'), range(-3 `z_crit') color(red) dropline(0))		
		(function y=normalden(x,`mu_null',`sd'), range(`z_crit' 6) recast(area) color(red)), 	
		title("Alpha Level for Distribution Assuming {&mu}={&mu}{subscript:0}") 				
		xtitle("{it: z}") xlabel(-3 -2 -1 0 1 2 3 4 5 6) legend(off) 				
		ytitle("Density") yscale(range(0 0.6))  ylabel(0(0.1)0.6, angle(horizontal) nogrid)
		text(0.45 0 "{&mu}{subscript:0}", color(red))
;
#delimit cr
graph export mu_null.png, as(png) width($Width16x9) height($Height16x9) replace


// NULL ONLY
#delimit ;
twoway  (function y=normalden(x,`mu_null',`sd'), range(-3 6) color(red) dropline(0)),  		
		title("Distribution of z assuming the Null Hypothesis: {&mu}={&mu}{subscript:0}") 	
		xtitle("{it: z}") xlabel(-3 -2 -1 0 1 2 3 4 5 6) legend(off) 					
		ytitle("Density") yscale(range(0 0.6))  ylabel(0(0.1)0.6, angle(horizontal) nogrid)
		text(0.45 0 "{&mu}{subscript:0}", color(red))
;
#delimit cr
graph export mu_nullonly.png, as(png) width($Width16x9) height($Height16x9) replace

	
// NULL AND ALTERNATIVE (red in front)
#delimit ;
twoway  (function y=normalden(x,`mu_null',`sd'), range(-3 `z_crit') color(red) dropline(0))
		(function y=normalden(x,`mu_alt',`sd'), range(-3 5) color(green)  dropline(`mu_alt'))
		(function y=normalden(x,`mu_alt',`sd'), range(`z_crit' 6) recast(area) color(green))
		(function y=normalden(x,`mu_null',`sd'), range(`z_crit' 6) recast(area) color(red)),
		title("Power for {&mu}={&mu}{subscript:0} versus {&mu}={&mu}{subscript:A}")
		xtitle("{it: z}") xlabel(-3 -2 -1 0 1 2 3 4 5 6) legend(off) 				
		ytitle("Density") yscale(range(0 0.6))  ylabel(0(0.1)0.6, angle(horizontal) nogrid)	
		text(0.45 0 "{&mu}{subscript:0}", color(red)) 								
		text(0.45 `mu_alt' "{&mu}{subscript:A}", color(green))
;
#delimit cr
graph export mu_null_alt1.png, as(png) width($Width16x9) height($Height16x9) replace


	
	
// NULL AND ALTERNATIVE (Green in front)
#delimit ;
twoway  (function y=normalden(x,`mu_null',`sd'), range(-3 `z_crit') color(red) dropline(0))
		(function y=normalden(x,`mu_alt',`sd'), range(-3 5) color(green)  dropline(`mu_alt'))
		(function y=normalden(x,`mu_null',`sd'), range(`z_crit' 6) recast(area) color(red))
		(function y=normalden(x,`mu_alt',`sd'), range(`z_crit' 6) recast(area) color(green)),
		title("Power for {&mu}={&mu}{subscript:0} versus {&mu}={&mu}{subscript:A}") 	
		xtitle("{it: z}") xlabel(-3 -2 -1 0 1 2 3 4 5 6) legend(off) 					
		ytitle("Density") yscale(range(0 0.6))  ylabel(0(0.1)0.6, angle(horizontal) nogrid)
		text(0.45 0 "{&mu}{subscript:0}", color(red)) 									
		text(0.45 `mu_alt' "{&mu}{subscript:A}", color(green))
;
#delimit cr
graph export mu_null_alt1b.png, as(png) width($Width16x9) height($Height16x9) replace	
	
	
	
// NULL AND ALTERNATIVE
#delimit ;
twoway  (function y=normalden(x,`mu_null',`sd'), range(-3 6) color(red) dropline(0))
		(function y=normalden(x,`mu_alt',`sd'), range(-3 6) color(green)  dropline(`mu_alt')),
		title("Distribution of z Assuming the Null ({&mu}={&mu}{subscript:0}) and Alternative ({&mu}={&mu}{subscript:A}) Hypotheses")
		xtitle("{it: z}") xlabel(-3 -2 -1 0 1 2 3 4 5 6) legend(off) 					
		ytitle("Density") yscale(range(0 0.6))  ylabel(0(0.1)0.6, angle(horizontal) nogrid)	
		text(0.45 0 "{&mu}{subscript:0}", color(red)) 
		text(0.45 `mu_alt' "{&mu}{subscript:A}", color(green))
;
#delimit cr
graph export mu_null_alt1only.png, as(png) width($Width16x9) height($Height16x9) replace
	


	
	
	
	
	
	
local mu_null = 0
local mu_alt = 1
local sd = 1
local z_crit = round(-1*invnormal(0.05), 0.01)
local z_crit_label = `z_crit' + 0.75


// NULL ONLY
#delimit ;
twoway  (function y=normalden(x,`mu_null',`sd'), range(-3 `z_crit') color(black) dropline(0))		
		(function y=normalden(x,`mu_null',`sd'), range(`z_crit' 3) recast(area) color(black)), 	
		xtitle("{it: z}", size(huge)) xlabel(-3 0 1.64 3, labsize(huge)) legend(off) 				
		ytitle("") yscale(range(0 0.5))  ylabel(0(0.1)0.5, angle(horizontal) nogrid)
		scheme(s1color)
;
#delimit cr
graph export z_alpha.png, as(png) width($Width16x9) height($Height16x9) replace



	
	
local mu_null = 0
local mu_alt = 1
local sd = 1
local z_crit = round(-1*invnormal(0.80), 0.01)
local z_crit_label = `z_crit' + 0.75


// NULL ONLY
#delimit ;
twoway  (function y=normalden(x,`mu_null',`sd'), range(-3 3) color(black) dropline(0))		
		(function y=normalden(x,`mu_null',`sd'), range(`z_crit' 3) recast(area) color(black)), 	
		xtitle("{it: z}", size(huge)) xlabel(-3 -0.84 0 3, labsize(huge)) legend(off) 				
		ytitle("Density") yscale(range(0 0.5))  ylabel(0(0.1)0.5, angle(horizontal) nogrid)
		scheme(s1color)
;
#delimit cr
graph export z_beta.png, as(png) width($Width16x9) height($Height16x9) replace




power onemean 0 1, n(5) knownsd fpc(0.05(0.01)0.15) onesided graph(ydimension(power) xdimension(fpc))
graph export "Graph_fpc.png", as(png) width($Width16x9) height($Height16x9) replace



power mcc 0.1, oratio(1.4) m(1(1)5) graph(ydimension(N) xdimension(M))
graph export "mcc_graph.png", as(png) width($Width16x9) height($Height16x9) replace


power cmh 0.25 0.3 0.3 0.35, oratio(1.2(0.1)2.0) graph(ydimension(N) xdimension(oratio))
graph export "cmh_graph.png", as(png) width($Width16x9) height($Height16x9) replace


power logrank, power(0.8) n(100(100)500) direction(upper) graph(ydimension(hratio) xdimension(N))
graph export "logrank_graph.png", as(png) width($Width16x9) height($Height16x9) replace















